Argument Parser — Python Kaos Utils documentation

# Argument Parser

class py_kaos_utils.argparse.ArgParseTypes

  Bases: `object`

  Contains static methods that can be passed to `argparse.ArgumentParser().add_argument(type=)`

  Example:

        >>> import argparse
        >>> parser = argparse.ArgumentParser()
        >>> parser.add_argument('datetime', type=ArgParseTypes.datetime)

  static datetime(s)

    Return a datetime parsed from a cli argument.